netapp_ontap.models.analytics_info API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.analytics_info`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AnalyticsInfoSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AnalyticsInfo object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `by_accessed_time: AnalyticsInfoByAccessedTime GET POST PATCH`

    File system analytics information, broken down by date of last access.

  `by_modified_time: AnalyticsInfoByModifiedTime GET POST PATCH`

    File system analytics information, broken down by date of last modification.

  `bytes_used: Size GET POST PATCH`

    Number of bytes used on-disk

    Example: 15436648448

  `file_count: Size GET POST PATCH`

    Number of descendants

    Example: 21134

  `incomplete_data: bool GET POST PATCH`

    Returns true if data collection is incomplete for this directory tree.

  `report_time: ImpreciseDateTime GET POST PATCH`

    The date and time analytics information was collected.

  `subdir_count: Size GET POST PATCH`

    Number of sub directories

    Example: 35